src.MEDS\_tabular\_automl.describe\_codes
=========================================

.. automodule:: src.MEDS_tabular_automl.describe_codes







   .. rubric:: Functions

   .. autosummary::

      clear_code_aggregation_suffix
      compute_feature_frequencies
      convert_to_df
      convert_to_freq_dict
      filter_parquet
      filter_to_codes
      get_feature_columns
      get_feature_freqs
